from autobr.baidu import BaiduNewsSearch,BaiduWebSearch
import os

def get_baidu_news(keywords,max_page=10,silent=True, driver_path="browsers/chromedriver.exe",save_path=""):
    baidu_news = BaiduNewsSearch(
        webdriver_path=driver_path,
    )
    baidu_news.fetch(raw_keywords=keywords,
                     max_pages=max_page,
                     silent=silent,
                     save_path=save_path)

def get_baidu_pages(keywords,max_page=10,silent=True, driver_path="browsers/chromedriver.exe",save_path=""):
    baidu_pages = BaiduWebSearch(
        webdriver_path=driver_path,
    )

    baidu_pages.fetch(raw_keywords=keywords, max_pages=max_page, silent=silent, save_path=save_path)

def get_baidu_news_with_keyword_combination(first_keyword_path,second_keyword_path,
                max_search_page=10,silent=True, driver_path="browsers/chromedriver.exe",save_folder=""
                                            ):

    country_keywords = [w.strip() for w in open(first_keyword_path, 'r', encoding='utf-8').readlines() if
                        w.strip() != ""]

    carbon2_keywords = [w.strip() for w in open(second_keyword_path, 'r', encoding='utf-8').readlines() if
                        w.strip() != ""]

    print(country_keywords)
    print(carbon2_keywords)

    baidu_news = BaiduNewsSearch(
        webdriver_path=driver_path,
    )

    for country in country_keywords:
        for keyword in carbon2_keywords:
            search_keyword = f"{country} {keyword}"
            print(f"Searching news.baidu.com with the keywords \"{search_keyword}\"...")
            try:
                if not os.path.exists(save_folder):
                    os.mkdir(save_folder)
                saved_path = f"{save_folder}/{search_keyword}-{max_search_page}.csv"
                if open(saved_path, 'r', encoding='utf-8').read().strip() == "title,baidu_url,real_url":
                    baidu_news.fetch(raw_keywords=search_keyword, max_pages=max_search_page, silent=silent,
                                     save_path=saved_path)
            except Exception as err:
                print(err)


def get_baidu_pages_with_keyword_combination(first_keyword_path, second_keyword_path,
                                            max_search_page=10, silent=False, driver_path="browsers/chromedriver.exe",
                                            save_folder=""
                                            ):
    country_keywords = [w.strip() for w in open(first_keyword_path, 'r', encoding='utf-8').readlines() if
                        w.strip() != ""]

    carbon2_keywords = [w.strip() for w in open(second_keyword_path, 'r', encoding='utf-8').readlines() if
                        w.strip() != ""]

    print(country_keywords)
    print(carbon2_keywords)

    baidu_pages = BaiduWebSearch(
        webdriver_path=driver_path,
    )

    for country in country_keywords:
        for keyword in carbon2_keywords:
            search_keyword = f"{country} {keyword}"
            print(f"Searching www.baidu.com with the keywords \"{search_keyword}\"...")
            try:
                if not os.path.exists(save_folder):
                    os.mkdir(save_folder)
                saved_path = f"{save_folder}/{search_keyword}-{max_search_page}.csv"
                if open(saved_path, 'r', encoding='utf-8').read().strip() == "title,baidu_url,real_url":
                    baidu_pages.fetch(raw_keywords=search_keyword, max_pages=max_search_page, silent=silent,
                                     save_path=saved_path)
            except Exception as err:
                print(err)


from selenium import webdriver
import time
import requests
from bs4 import BeautifulSoup
import csv

def get_rea_url_from(b_url):
    try:
        r = requests.get(b_url)
        if r.url!=b_url:
            return r.url

        obj = BeautifulSoup(r.text, features='lxml')
        meta = obj.find("noscript").find("meta")
        real_url = meta["content"].split(";")[1].split("'")[1]

        return real_url
    except:
        return ""

def init_browser(init_url, driver_path=r"D:\web\chromedriver_win32\chromedriver.exe",implicitly_wait=0.5,wait_after_init=10):
    # set chromodriver.exe path
    driver = webdriver.Chrome(driver_path)
    driver.implicitly_wait(implicitly_wait)
    # launch URL: verify
    driver.get(init_url)
    # identify search box
    # body = driver.find_element_by_tag_name("body")

    # print(body.text)

    # print(body.get_attribute("outerHTML"))

    # print()

    time.sleep(wait_after_init)

    # print("current url: ", driver.current_url)
    return driver

def start(init_url,url_format,save_path,field_names,driver_path, encoding='utf-8'):
    driver = init_browser(init_url=init_url,driver_path=driver_path)
    with open(save_path, 'w', newline='', encoding=encoding) as csvfile:
        writer = csv.DictWriter(csvfile, fieldnames=field_names)
        writer.writeheader()
        for pi in range(0, 1000):
            print("Page ", pi)
            search_url=url_format.replace("{pi}",str(pi*10))
            list_model = get_search_page_model(driver, search_url)
            writer.writerows(list_model)
            csvfile.flush()
            time.sleep(5)
        print()

def get_search_page_model(driver,search_url):
    driver.get(search_url)
    time.sleep(1)
    body = driver.find_element_by_tag_name("body")
    html_obj = BeautifulSoup(body.get_attribute("outerHTML"), features='lxml')

    h3s = html_obj.findAll("h3", {"class": "t"})
    list_model=[]
    for h3 in h3s:
        title = h3.find("a").text
        b_url = h3.find("a")["href"]
        print(title)
        print(b_url)
        try:
            driver.get(b_url)
            time.sleep(3)
            real_url = driver.current_url
        except:
            print("error in ", b_url)
            real_url = ""
        print("Real Url: ",real_url)
        # real_url=get_rea_url_from(baidu_url)
        print()
        # print(h3.find("a").text, h3.find("a")["href"], real_url)
        model = {
            "title": title,
            "b_url": b_url,
            "real_url": real_url
        }
        list_model.append(model)
    return list_model



from selenium import webdriver
import time
import requests
from bs4 import BeautifulSoup
import csv
import urllib.parse
import datetime

class BaiduNewsSearch:
    def __init__(self,
                 webdriver_path="browsers/chromedriver.exe",
                 ):

        # -------------设置参数-----------------
        self.webdriver_path = webdriver_path
        # -------------结束设置参数-----------------

        pass

    def get_rea_url_from_baidu(self,baidu_url):
        try:
            r = requests.get(baidu_url)
            if r.url != baidu_url:
                return r.url
            obj = BeautifulSoup(r.text, features='lxml')
            meta = obj.find("noscript").find("meta")
            real_url = meta["content"].split(";")[1].split("'")[1]
            return real_url
        except:
            return ""

    def get_search_page_model(self,baidu_search_url):

        self.driver.get(baidu_search_url)
        time.sleep(1)
        body = self.driver.find_element_by_tag_name("body")

        # print(body.get_attribute("outerHTML"))

        html_obj = BeautifulSoup(body.get_attribute("outerHTML"), features='lxml')
        result_list = html_obj.findAll("div",{"class":"result-op c-container xpath-log new-pmd"})
        # h3s = html_obj.findAll("h3")

        list_model = []
        for result in result_list:
            h3=result.find("div").find("h3")
            news_time=""

            if h3.find("a")==None:
                continue
            title = h3.find("a").text.strip()
            baidu_url = h3.find("a")["href"]
            print(title)
            print("Baidu url: ", baidu_url)

            try:

                # driver.get(baidu_url)
                # time.sleep(3)
                # real_url = driver.current_url
                real_url = baidu_url

            except:
                print("error in ", baidu_url)
                real_url = ""

            try:
                news_time = result.find("div").find("div").find("div",{"class":"c-span-last"}).find("span").text

                today = datetime.datetime.today()
                year = today.year
                month = today.month

                if '年' in news_time and '月' in news_time and '日' in news_time:
                    news_time=news_time.replace("年","-").replace("月","-").replace("日","").strip()
                if ('年' not in news_time) and '月' in news_time and '日' in news_time:
                    news_time = str(year) +"-"+ news_time.replace("月", "-").replace("日", "").strip()
                if '天前' in news_time:
                    day=news_time.replace('天前','').strip()
                    new_today=today+datetime.timedelta(days=-int(day))
                    news_time=new_today.strftime("%Y-%m-%d")
                if '小时前' in news_time or '分钟前' in news_time or '刚刚' in news_time:
                    news_time = today.strftime("%Y-%m-%d")
                if '昨天' in news_time:
                    new_today=today+datetime.timedelta(days=-1)
                    news_time=new_today.strftime("%Y-%m-%d")
                if '今天' in news_time:
                    news_time=today.strftime("%Y-%m-%d")

            except:
                news_time=""
                print("error in extracting news_time...")

            print("Real Url: ", real_url)
            print("News time: ",news_time)
            # real_url=get_rea_url_from_baidu(baidu_url)
            print()
            # print(h3.find("a").text, h3.find("a")["href"], real_url)
            model = {
                "title": title,
                "baidu_url": baidu_url,
                "real_url": real_url,
                "news_time":news_time
            }
            list_model.append(model)
        return list_model

    def fetch(self,raw_keywords,
                implicitly_wait=0.5,
                seconds_wait=10,
                func_process=None,
                silent=False,
                max_pages=100,
                save_path="",
                sleep_seconds_before_going_to_next_page=3,min_pages=0,retry_max_num=10,use_medium=False,use_sort=False):
        keywords = urllib.parse.quote(raw_keywords)
        if silent:
            options = webdriver.ChromeOptions()
            options.add_argument("--log-level=3")
            options.headless = True
            self.driver = webdriver.Chrome(executable_path=self.webdriver_path,
                                      chrome_options=options
                                      )
        else:
            self.driver = webdriver.Chrome(executable_path=self.webdriver_path)

        self.driver.implicitly_wait(implicitly_wait)

        # 首次打开，可能需要手动验证相关，验证后，等待10s再自动获取搜索结果列表
        if use_medium:
            url = f"https://www.baidu.com/s?medium=1&tn=news&word={keywords}"
        else:
            url=f"https://www.baidu.com/s?tn=news&word={keywords}"

        if use_sort:
            url+="&rtt=4"
        else:
            url += "&rtt=1"
        self.driver.get(url)

        # body = self.driver.find_element_by_tag_name("body")

        # print(body.text)
        # print(body.get_attribute("outerHTML"))
        # print()
        print("Waiting...")
        print("若百度页面弹出验证页面，请手动通过验证，在10秒内完成！一般来说，验证一次后面就无须验证！")
        time.sleep(seconds_wait)

        # print("current url: ",driver.current_url)

        print("Start to fetch list  ...")

        field_names = ["title", "baidu_url", "real_url","news_time"]
        encoding = 'utf-8'
        if save_path!="":
            with open(save_path, 'w', newline='', encoding=encoding) as csvfile:
                writer = csv.DictWriter(csvfile, fieldnames=field_names)
                writer.writeheader()
                pi=min_pages
                max_try=retry_max_num
                while pi<=max_pages:
                    if max_try<retry_max_num:
                        print(f"\tRetrying #{retry_max_num - max_try}...")
                    else:
                        print("Page ", pi + 1)
                    if use_medium:
                        baidu_search_url = f"https://www.baidu.com/s?ie=utf-8&medium=1&bsst=1&rsv_dl=news_t_sk&cl=2&wd={keywords}&tn=news&rsv_bp=1&tfflag=0&pn={10 * pi}"
                    else:
                        baidu_search_url = f"https://www.baidu.com/s?tn=news&word={keywords}&pn={10 * pi}"
                    if use_sort:
                        baidu_search_url += "&rtt=4"
                    else:
                        baidu_search_url += "&rtt=1"

                    print(baidu_search_url)
                    list_model = self.get_search_page_model(baidu_search_url)
                    if func_process != None:
                        func_process(list_model)
                    writer.writerows(list_model)
                    csvfile.flush()

                    if len(list_model)!=0 or max_try<=0:
                        time.sleep(sleep_seconds_before_going_to_next_page)
                        pi+=1
                        max_try=retry_max_num
                        print()
                    else:
                        waiting=8
                        if retry_max_num-max_try<3:
                            waiting=sleep_seconds_before_going_to_next_page*(retry_max_num-max_try+1)
                        else:
                            waiting=60*5
                        time.sleep(waiting)
                        print(f"\tWaiting: {waiting} seconds...")
                        max_try-=1
                print()
        else:
            pi = min_pages
            max_try = retry_max_num
            while pi <= max_pages:
                if max_try < retry_max_num:
                    print(f"Retrying #{retry_max_num - max_try}...")
                else:
                    print("Page ", pi + 1)
                # baidu_search_url = f"https://www.baidu.com/s?tn=news&word={keywords}&pn={10 * pi}"
                if use_medium:
                    baidu_search_url = f"https://www.baidu.com/s?ie=utf-8&medium=1&bsst=1&rsv_dl=news_t_sk&cl=2&wd={keywords}&tn=news&rsv_bp=1&tfflag=0&pn={10 * pi}"
                else:
                    baidu_search_url = f"https://www.baidu.com/s?tn=news&word={keywords}&pn={10 * pi}"
                if use_sort:
                    baidu_search_url += "&rtt=4"
                else:
                    baidu_search_url += "&rtt=1"
                list_model = self.get_search_page_model(baidu_search_url)
                if func_process != None:
                    func_process(list_model)
                time.sleep(sleep_seconds_before_going_to_next_page)
                if len(list_model) != 0 or max_try <= 0:
                    pi += 1
                    max_try = retry_max_num
                    print()
                else:
                    max_try -= 1
            print()


        self.driver.close()

class BaiduWebSearch:
    def __init__(self,
                 webdriver_path="browsers/chromedriver.exe",

                 ):

        # -------------设置参数-----------------

        self.webdriver_path = webdriver_path

        # -------------结束设置参数-----------------



        pass

    def get_rea_url_from_baidu(self, baidu_url):
        try:
            r = requests.get(baidu_url)
            if r.url != baidu_url:
                return r.url
            obj = BeautifulSoup(r.text, features='lxml')
            meta = obj.find("noscript").find("meta")
            real_url = meta["content"].split(";")[1].split("'")[1]
            return real_url
        except:
            return ""

    def get_search_page_model(self, baidu_search_url, sleep_seconds_after_visit_page=3):

        self.driver.get(baidu_search_url)
        time.sleep(1)
        body = self.driver.find_element_by_tag_name("body")

        # print(body.get_attribute("outerHTML"))

        html_obj = BeautifulSoup(body.get_attribute("outerHTML"), features='lxml')

        h3s = html_obj.findAll("h3", {"class": "t"})
        list_model = []
        for h3 in h3s:
            title = h3.find("a").text
            baidu_url = h3.find("a")["href"]
            print(title)
            print("Baidu url: ", baidu_url)
            try:
                self.driver.get(baidu_url)
                time.sleep(sleep_seconds_after_visit_page)
                real_url = self.driver.current_url
                # real_url = baidu_url
            except:
                print("error in ", baidu_url)
                real_url = ""
            print("Real Url: ", real_url)
            # real_url=get_rea_url_from_baidu(baidu_url)
            print()
            # print(h3.find("a").text, h3.find("a")["href"], real_url)
            model = {
                "title": title,
                "baidu_url": baidu_url,
                "real_url": real_url
            }
            list_model.append(model)
        return list_model

    def fetch(self, raw_keywords, implicitly_wait=0.5, seconds_wait=10, func_process=None,silent=False,
              max_pages=100,
              save_path="",
              sleep_seconds_before_going_to_next_page=5,
              sleep_seconds_after_visit_page=3
              ):
        keywords = urllib.parse.quote(raw_keywords)
        if silent:
            options = webdriver.ChromeOptions()
            options.add_argument("--log-level=3")
            options.headless = True
            self.driver = webdriver.Chrome(executable_path=self.webdriver_path,
                                           chrome_options=options
                                           )
        else:
            self.driver = webdriver.Chrome(executable_path=self.webdriver_path)


        self.driver.implicitly_wait(implicitly_wait)

        # 首次打开，可能需要手动验证相关，验证后，等待10s再自动获取搜索结果列表
        self.driver.get(f"https://www.baidu.com/s?t&wd={keywords}")

        body = self.driver.find_element_by_tag_name("body")

        # print(body.text)
        # print(body.get_attribute("outerHTML"))
        # print()
        print("Waiting...")
        print("若百度页面弹出验证页面，请手动通过验证，在10秒内完成！一般来说，验证一次后面就无须验证！")
        time.sleep(seconds_wait)

        # print("current url: ",driver.current_url)

        print("Start to fetch list  ...")

        field_names = ["title", "baidu_url", "real_url"]
        encoding = 'utf-8'
        if save_path!="":
            with open(save_path, 'w', newline='', encoding=encoding) as csvfile:
                writer = csv.DictWriter(csvfile, fieldnames=field_names)
                writer.writeheader()
                for pi in range(0, max_pages):
                    print("Page ", pi + 1)
                    baidu_search_url = f"https://www.baidu.com/s?wd={keywords}&pn={10 * pi}"
                    list_model = self.get_search_page_model(baidu_search_url,sleep_seconds_after_visit_page)
                    if func_process != None:
                        func_process(list_model)
                    writer.writerows(list_model)
                    csvfile.flush()
                    time.sleep(sleep_seconds_before_going_to_next_page)
                print()
        else:
            for pi in range(0, max_pages):
                print("Page ", pi + 1)
                baidu_search_url = f"https://www.baidu.com/s?wd={keywords}&pn={10 * pi}"
                list_model = self.get_search_page_model(baidu_search_url)
                if func_process != None:
                    func_process(list_model)
                time.sleep(sleep_seconds_before_going_to_next_page)
            print()

        self.driver.close()




from carbon2.api.submit_list import *

def extract_text(html_str):
    content = bare_extraction(html_str)
    if content == None:
        return ""
    return content['text']

def extract_content(html_str):
    content = bare_extraction(html_str)
    return content

def download_html_data(
    input_csv_file = "data/list_urls.csv",
    save_folder = "data/html_data",
    output_csv_file="data/list_news.csv"
):
    server_url = ""
    user_id = ""
    if not os.path.exists(save_folder):
        os.mkdir(save_folder)

    list_result=submit_page_list(server_url, user_id, input_csv_file, save_html_folder=save_folder, use_md5url_as_id=True,
                     #  driver_path="browsers/chromedriver.exe",
                     tag="auto", language="zh", try_raise_error=False,no_submit=True,no_submit_file=True,not_check_exists=True)
    print("list_result = ",list_result)
    qc_write(output_csv_file,list_result)

def fetch_raw_text(
        input_csv_path='data/list_country_news_plus.csv',
        output_html_folder='data/html_data',
        output_text_folder='data/text_data',
        output_csv_path='data/list_g20_news_plus_text.csv'
):

    if not os.path.exists(output_text_folder):
        os.mkdir(output_text_folder)

    list_g20_news = qc.quick_read_csv_model(csv_path=input_csv_path)

    list_item_new = []

    N = len(list_g20_news)

    for idx, item in enumerate(list_g20_news):
        print(f'{idx + 1}/{N}')
        file_id = item["FileId"]
        filepath = f'{output_html_folder}/{file_id}.txt'
        full_text = ""
        if not os.path.exists(filepath):
            continue
        content=extract_content(open(filepath, 'r', encoding='utf-8').read())
        if content==None:
            continue
        full_text = content["text"]
        f_out = open(f"{output_text_folder}/{file_id}.txt", "w", encoding='utf-8')
        f_out.write(full_text)
        f_out.close()
        # item["Text"]=full_text.replace("\n","").replace("\"","'").strip()
            # add additional fields

        item['PublishTime'] = content['date']
        item['HostName'] = content['hostname']
        item['Publisher'] = content['author']

        list_item_new.append(item)
        print(full_text)
        print()

    qc.qc_write(output_csv_path, list_item_new)

from quickcsv.file import *

def add_additional_info(
        input_origin_url_csv_path="",
        input_meta_csv_path="",
        add_field="country",
        output_csv_path=""

):
    list_item = qc_read(input_origin_url_csv_path)
    dict_url_country = {}
    dict_country = {}
    for item in list_item:
        if not item[add_field] in dict_url_country.keys():
            dict_url_country[item["real_url"]] = item[add_field]
        if not item[add_field] in dict_country.keys():
            dict_country[item[add_field]] = 1
        else:
            dict_country[item[add_field]] += 1
    print()
    for country in dict_country.keys():
        print(f"{country}\t{dict_country[country]}")

    count = 0
    list_news = qc_read(input_meta_csv_path)
    list_result = []
    for news in list_news:
        url = news["Url"]
        if url in dict_url_country:
            country = dict_url_country[url]
            news["Tag"] = country
            list_result.append(news)

    qc_write(output_csv_path, list_result)

    print("exist count = ", count)

import quickcsv.file as qc
from trafilatura import bare_extraction
import os
from nerkit.StanzaApi import StanzaWrapper

def get_important_text(
        input_keywords_paths=None,
        input_csv_added="",
        input_text_folder='',
        output_text_processed_folder='',
        output_csv_file=''
):

    sw = StanzaWrapper()
    all_keywords=[]
    for path in input_keywords_paths:
        keywords = [w.strip() for w in open(path, 'r', encoding='utf-8').readlines()
                        if w.strip() != ""]
        all_keywords+=keywords

    list_g20_news = qc.quick_read_csv_model(csv_path=input_csv_added)

    list_item_new = []

    N = len(list_g20_news)

    if not os.path.exists(output_text_processed_folder):
        os.mkdir(output_text_processed_folder)

    for idx, item in enumerate(list_g20_news):
        print(f'{idx + 1}/{N}')
        # print(item)
        file_id = item["FileId"]
        save_text_path = f"{input_text_folder}/{file_id}.txt"
        if not os.path.exists(save_text_path):
            continue
        text = open(save_text_path, 'r', encoding='utf-8').read()
        # print(text)
        if text == '':
            continue
        list_sentence = sw.tokenize_sentence(text, lang='zh')
        list_sentence_useful = []
        for sentence in list_sentence:
            # print(sentence)
            if len(sentence) < 30:
                continue
            sentence = sentence.strip()
            sub_sentences = sentence.split("\n")
            for sub_sentence in sub_sentences:
                sub_sentence = sub_sentence.strip()
                if len(sub_sentence) <= 20:
                    continue

                has_found_keywords = False
                for k in all_keywords:
                    if k in sub_sentence:
                        has_found_keywords = True
                        break
                if has_found_keywords:
                    print(sub_sentence)
                    list_sentence_useful.append(sub_sentence)

        if len(list_sentence_useful) != 0:
            new_text = '\n'.join(list_sentence_useful)
            processed_text_path = f"{output_text_processed_folder}/{file_id}.txt"
            f_out = open(processed_text_path, 'w', encoding='utf-8')
            f_out.write(new_text)
            f_out.close()
            list_item_new.append(item)

    qc.qc_write(output_csv_file, list_item_new)

def fetch_and_preprocess_pipeline(
    input_urls_path = 'data/list_urls.csv',
    keywords_path = 'data/keywords'
):

    download_html_data(input_csv_file=input_urls_path, output_csv_file='data/list_news.csv')

    fetch_raw_text(input_csv_path='data/list_news.csv', output_csv_path='data/list_news_meta.csv')

    add_additional_info(
        add_field='countries',
        input_origin_url_csv_path=input_urls_path,
        input_meta_csv_path="data/list_news_meta.csv",
        output_csv_path="data/list_news_added.csv"
    )

    kp = []
    for file in os.listdir(keywords_path):
        kp.append(os.path.join(keywords_path, file))

    get_important_text(
        input_keywords_paths=kp,
        input_text_folder='data/text_data',
        input_csv_added='data/list_news_added.csv',
        output_csv_file='data/list_news_useful.csv',
        output_text_processed_folder='data/text_data_processed'
    )

if __name__=="__main__":
    fetch_and_preprocess_pipeline()








from autobr.baidu import BaiduNewsSearch
import os
import time
from quickcsv.file import *
from carbon2.analysis.similarity import analyze_similar_document_pairs
import quickcsv.file as qc

def search_data_and_download(root_folder="data", groupby="countries", keywords="carbon2",
                             driver_path="../browsers/chromedriver.exe",
                             max_search_page=100,
                             top_keywords_num=5
                             ):
    country_keywords = [w.strip() for w in
                        open(f'{root_folder}/keywords/{groupby}.csv', 'r', encoding='utf-8').readlines() if
                        w.strip() != ""]

    carbon2_keywords = [w.strip() for w in
                        open(f'{root_folder}/keywords/{keywords}.csv', 'r', encoding='utf-8').readlines() if
                        w.strip() != ""]

    print(country_keywords)
    print(carbon2_keywords)

    baidu_news = BaiduNewsSearch(
        webdriver_path=driver_path,
    )

    # max_search_page = 100
    # top_keywords_num = 5


    for country in country_keywords:
        for keyword in carbon2_keywords[:top_keywords_num]:
            search_keyword = f"{country} {keyword}"
            print(country)
            print(f"Searching news.baidu.com with the keywords \"{search_keyword}\"...")
            try:
                country_path = f"{root_folder}/results/{groupby}/{country}"
                if not os.path.exists(country_path):
                    os.mkdir(country_path)
                filename = time.strftime("%Y%m%d%H%M%S", time.localtime())
                saved_path = f"{country_path}/{filename}.csv"
                baidu_news.fetch(raw_keywords=search_keyword, max_pages=max_search_page, silent=False,
                                 save_path=saved_path)
            except Exception as err:
                print(err)


def summarize_csv(root_path="data/search_results/country", output_path='list_country_news1.csv',
                  real_url_field='real_url', group_by_field='GroupBy', id_field="Id"):
    list_id = []

    list_result = []
    idx = 0
    for country in os.listdir(root_path):
        file_path = os.path.join(root_path, country)
        for file in os.listdir(file_path):
            csv_path = os.path.join(file_path, file)
            list_item = qc_read(csv_path)
            for item in list_item:
                real_url = item[real_url_field]
                if real_url not in list_id:
                    list_id.append(real_url)
                    item[group_by_field] = country
                    item[id_field] = idx
                    list_result.append(item)
                    idx += 1

    print("len = ", len(list_result))

    qc_write(output_path, list_result)


def get_similar(input_path="list_country_news2.csv", stopwords_path="data/stopwords/hit_stopwords.txt",
                analyze_field="title",
                save_path="list_country_news_similarity_report2.csv", similarity=0.7):
    analyze_similar_document_pairs(
        csv_path=input_path,  # 这是系统导出数据产生的csv格式文件
        stopwords_path=stopwords_path,  # 用于清除停用词
        analyze_field=analyze_field,  # 相似度分析的csv字段，标题为Title，或者如果csv文件某一列是正文，也可以是正文的列名
        save_similar_result_path=save_path,  # 相似度分析的保存结果，每一行为一对文档的标题。
        need_similarity=True,  # 在输出的文件中包含相似度这一列
        minimum_similarity=similarity  # need_similarity==True情况下，只保存相似度大于minimum_similarity的文档对，取值在[0,1]
    )


def remove_similar(similarity_report_path="",
                   input_csv_path='',
                   output_path=''
                   ):
    list_sim = qc.quick_read_csv_model(csv_path=similarity_report_path)
    dict_sim = {}
    for item in list_sim:
        id1 = item['Id1']
        id2 = item['Id2']
        if id1 in dict_sim.keys():
            if id2 not in dict_sim[id1]:
                dict_sim[id1].append(id2)
        else:
            dict_sim[id1] = [id2]
        if id2 in dict_sim.keys():
            if id1 not in dict_sim[id2]:
                dict_sim[id2].append(id1)
        else:
            dict_sim[id2] = [id1]

    list_g20_news_merge3 = qc.quick_read_csv_model(csv_path=input_csv_path)

    list_ids = []
    list_result = []

    def exists_pair(id1, id2):
        if id1 in dict_sim.keys():
            if id2 in dict_sim[id1]:
                return True
        if id2 in dict_sim.keys():
            if id1 in dict_sim[id2]:
                return True
        return False

    def exists_pair_in_list(id1, list_ids):
        for id2 in list_ids:
            flag = exists_pair(id1, id2)
            if flag == True:
                return True
        return False

    N = len(list_g20_news_merge3)

    for idx, item in enumerate(list_g20_news_merge3):
        id = item['Id']
        print(f"{idx + 1}/{N}")
        if not exists_pair_in_list(id, list_ids):
            list_result.append(item)
            list_ids.append(id)
        print()

    qc.qc_write(output_path, list_result)


def auto_search_download(
        root_path="test_method",
        groupby='countries',
        keywords="carbon2",
        max_search_page=2,
        top_keywords_num=2,
        driver_path='../browsers/chromedriver.exe'
):
    result_folder = f'{root_path}/results'
    if not os.path.exists(result_folder):
        os.mkdir(result_folder)

    result_groupby_folder = f'{result_folder}/{groupby}'
    if not os.path.exists(result_groupby_folder):
        os.mkdir(result_groupby_folder)

    search_data_and_download(
        root_folder=root_path,
        groupby=groupby,
        keywords=keywords,
        driver_path=driver_path,
        max_search_page=max_search_page,
        top_keywords_num=top_keywords_num
    )

    summarize_csv(
        root_path=result_groupby_folder,
        output_path=f'{root_path}/results/list_news.csv',
        group_by_field=groupby
    )
    get_similar(
        input_path=f'{root_path}/results/list_news.csv',
        similarity=0.7,
        save_path=f'{root_path}/results/similarity_report.csv',
        # stopwords_path=f'{root_path}/stopwords/stopwords',
        stopwords_path='',
        analyze_field='title'
    )
    remove_similar(
        similarity_report_path=f'{root_path}/results/similarity_report.csv',
        input_csv_path=f'{root_path}/results/list_news.csv',
        output_path=f'{root_path}/results/list_news_without_similar.csv',
    )
    print("output: ", f'{root_path}/results/list_news_without_similar.csv')
